@@ -11,9 +11,7 @@
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
-* License along with this library; if not, write to the
-* Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-* Boston, MA 02111-1307, USA.
+* License along with this library; if not, see <http://www.gnu.org/licenses/>.
 *
 * Author: Meg Ford <megford@gnome.org>
 *
@@ -27,8 +25,6 @@ const GdkPixbuf = imports.gi.GdkPixbuf;
 const Gio = imports.gi.Gio;
 const Gst = imports.gi.Gst;
 
-const Signals = imports.signals;
-
 const AudioProfile = imports.audioProfile;
 const FileUtil = imports.fileUtil;
 const Info = imports.info;
@@ -40,13 +36,11 @@ const Waveform = imports.waveform;
 
 let activeProfile = null;
 let audioProfile = null;
-let fileUtil = null;
 let grid = null;
 let groupGrid;
 let list = null;
 let loadMoreButton = null;
 let offsetController = null;
-let path = null;
 let play = null;
 let previousSelRow = null;
 let recordPipeline = null;
@@ -90,56 +84,31 @@ const MainWindow = new Lang.Class({
 
      _init: function(params) {
         audioProfile = new AudioProfile.AudioProfile();
-        this._buildFileName = new Record.BuildFileName()
-        path = this._buildFileName.buildPath();
-        this._buildFileName.ensureDirectory(path);
-        fileUtil = new FileUtil.FileUtil();
         offsetController = new FileUtil.OffsetController;
         view = new MainView();
         play = new Play.Play();
         
-        params = Params.fill(params, { title: GLib.get_application_name(), 
-                                       default_width: 700,
+        params = Params.fill(params, { title: GLib.get_application_name(),
+                                       hexpand: true,
+                                       vexpand: true, 
+                                       default_width: 675,
                                        default_height: 480 });
         this.parent(params);
-        
-        grid = new Gtk.Grid({ orientation: Gtk.Orientation.VERTICAL,
-                              halign: Gtk.Align.CENTER,
-                              height_request: 109,
-                              width_request: 900,
-                              border_width: 12,
-                              vexpand: false });
-        grid.set_row_homogeneous(true);
-        let stackSwitcher = Gtk.StackSwitcher.new();
-        stackSwitcher.set_stack(view);
-        let header = new Gtk.HeaderBar({ hexpand: true });
-        header.set_show_close_button(true);
+
+        let header = new Gtk.HeaderBar({ hexpand: true,
+                                         show_close_button: true });
         this.set_titlebar(header);
-        
-        let recordToolbar = new Gtk.Box({ orientation: Gtk.Orientation.HORIZONTAL,
-                                          spacing: 0 });
-        header.pack_start(recordToolbar);
-        recordButton = new RecordButton({ label: "Record",
+
+        recordButton = new RecordButton({ label: _("Record"),
                                           margin_bottom: 4,
                                           margin_top: 6,
                                           margin_left: 6,
                                           margin_right: 6 });
-        recordToolbar.pack_end(recordButton, false, true, 0);
-        recordToolbar.get_style_context().add_class('header');
-        recordToolbar.show();
-        recordButton.show();
+        recordButton.get_style_context().add_class('destructive-action');
+        header.pack_start(recordButton);
 
-        grid.add(view);
-            
-        this._defineThemes();
-                
-        this.add(grid);
-        grid.show_all();
+        this.add(view);
         this.show_all();
-    },
-       
-    _defineThemes: function() {
-        let settings = Gtk.Settings.get_default();
     }
 });
 
@@ -148,50 +117,71 @@ const MainView = new Lang.Class({
     Extends: Gtk.Stack,
 
     _init: function(params) {
-        params = Params.fill(params, { hexpand: false,
-                                       vexpand: false,
+        params = Params.fill(params, { hexpand: true,
+                                       vexpand: true,
                                        transition_type: Gtk.StackTransitionType.CROSSFADE,
                                        transition_duration: 100,
                                        visible: true });
         this.parent(params);
-            
-        let listviewPage = this._addListviewPage('listviewPage');
-            
+
+        this._addListviewPage('listviewPage');
         this.labelID = null;
     },
     
+    _addEmptyPage: function() {
+        this.emptyGrid = new Gtk.Grid({ orientation: Gtk.Orientation.VERTICAL,
+                                        hexpand: true,
+                                        vexpand: true,
+                                        halign: Gtk.Align.CENTER,
+                                        valign: Gtk.Align.CENTER });
+        this._scrolledWin.add(this.emptyGrid);
+
+        let emptyPageImage = new Gtk.Image({ icon_name: 'audio-input-microphone-symbolic',
+                                             icon_size: Gtk.IconSize.LARGE_TOOLBAR });
+        emptyPageImage.get_style_context().add_class('dim-label');
+        this.emptyGrid.add(emptyPageImage);
+        let emptyPageTitle = new Gtk.Label({ label: _("Add Recordings"),
+                                             halign: Gtk.Align.CENTER,
+                                             valign: Gtk.Align.CENTER });
+        emptyPageTitle.get_style_context().add_class('dim-label');
+        this.emptyGrid.add(emptyPageTitle);
+        let emptyPageDirections = new Gtk.Label({ label: _("Use the <b>Record</b> button to make sound recordings"),
+                                                  use_markup: true,
+                                                  max_width_chars: 30,
+                                                  halign: Gtk.Align.CENTER,
+                                                  valign: Gtk.Align.CENTER });
+        emptyPageDirections.get_style_context().add_class('dim-label');
+        this.emptyGrid.add(emptyPageDirections);
+        this.emptyGrid.show_all();
+    },        
+    
     _addListviewPage: function(name) {
-        fileUtil = new FileUtil.FileUtil();
         list = new Listview.Listview();
         list.setListTypeNew();
         list.enumerateDirectory();
         this._record = new Record.Record(audioProfile);
-        let initialPage = new Gtk.EventBox();
-        
+
         groupGrid = new Gtk.Grid({ orientation: Gtk.Orientation.VERTICAL,
-                                   halign: Gtk.Align.CENTER,
-                                   valign: Gtk.Align.CENTER,
-                                   row_spacing: 12,
+                                   hexpand: true,
+                                   vexpand: true,
                                    column_homogeneous: true });
-        groupGrid.add(initialPage);
         this.add_titled(groupGrid, name, "View");
     },
     
     onPlayStopClicked: function() {
         this.activeState = play.getPipeStates();
         let listRow = this.listBox.get_selected_row();
+        
         if (this.activeState == PipelineStates.PLAYING) {
             play.stopPlaying();
             let rowWidget = listRow.get_child(this.widget);
             rowWidget.foreach(Lang.bind(this,
                 function(child) {
                 
-                    if (child.name == "PauseToolbar") {
+                    if (child.name == "PauseButton") {
                         child.hide();
                         child.sensitive = false;
-                    }  
-                           
-                    if (child.name == "PlayToolBar" ) {
+                    } else {
                         child.show();
                         child.sensitive = true;
                     }
@@ -255,6 +245,7 @@ const MainView = new Lang.Class({
         this.recordGrid = new Gtk.Grid({ orientation: Gtk.Orientation.VERTICAL,
                                          height_request: 36,
                                          width_request: 400,
+                                         hexpand: true,
                                          name: "recordGrid" });
         this.recordGrid.set_orientation(Gtk.Orientation.HORIZONTAL);
         this.groupGrid.add(this.recordGrid);
@@ -289,13 +280,14 @@ const MainView = new Lang.Class({
         this.toolbarStart.get_style_context().add_class(Gtk.STYLE_CLASS_LINKED);
 
         // finish button (stop recording)
-        let stopRecord = new Gtk.Button({ label: "Finish",
+        let stopRecord = new Gtk.Button({ label: _("Finish"),
                                           margin_bottom: 4,
                                           margin_top: 6,
                                           margin_left: 6,
                                           margin_right: 6,
-                                          hexpand: true,
-                                          vexpand: true });
+                                          valign: Gtk.Align.CENTER,
+                                          hexpand: true });
+        stopRecord.get_style_context().add_class('text-button');
         stopRecord.connect("clicked", Lang.bind(this, this.onRecordStopClicked));
         this.toolbarStart.pack_start(stopRecord, true, true, 0);
         this.recordGrid.attach(this.toolbarStart, 5, 1, 1, 2);
@@ -303,12 +295,8 @@ const MainView = new Lang.Class({
      
     scrolledWinAdd: function() {    
         this._scrolledWin = new Gtk.ScrolledWindow({ shadow_type: Gtk.ShadowType.IN,
-                                                     margin_bottom: 3,
-                                                     margin_top: 5,
-                                                     hexpand: false,
-                                                     vexpand: false,
-                                                     width_request: 900,
-                                                     height_request: 400 });
+                                                     hexpand: true,
+                                                     vexpand: true });
         this._scrolledWin.set_policy(Gtk.PolicyType.NEVER, Gtk.PolicyType.AUTOMATIC);
         this._scrolledWin.get_style_context().add_class('view');
         this.scrollbar = this._scrolledWin.get_vadjustment();
@@ -328,208 +316,178 @@ const MainView = new Lang.Class({
         this.groupGrid.add(this._scrolledWin);
         this._scrolledWin.show();
         
-        this.listBox = Gtk.ListBox.new();
-        this._scrolledWin.add(this.listBox);
-        this.listBox.set_selection_mode(Gtk.SelectionMode.SINGLE);
-        this.listBox.set_header_func(null);
-        this.listBox.set_activate_on_single_click(true);
-        this.listBox.connect("row-selected", Lang.bind(this,
-            function(){
-                this.rowGridCallback(this.listBox.get_selected_row())
-            }));
-        this.listBox.show();
-        
+        this.listBox = null;
         this._startIdx = 0;
         this._endIdx = offsetController.getEndIdx();
-        this._files = [];
-        this._files = list.getFilesInfoForList();
         
-        for (let i = this._startIdx; i <= this._endIdx; i++) {
-            this.rowGrid = new Gtk.Grid({ orientation: Gtk.Orientation.VERTICAL,
-                                          height_request: 45,
-                                          width_request: 900,
-                                          name: i.toString() });
-            this.rowGrid.set_orientation(Gtk.Orientation.HORIZONTAL);
-            this.listBox.add(this.rowGrid);
-            this.rowGrid.show();
-            
-            this.widget = new Gtk.Toolbar({ show_arrow: false,
-                                            halign: Gtk.Align.END,
-                                            valign: Gtk.Align.FILL,
-                                            icon_size: Gtk.IconSize.BUTTON,
-                                            opacity: 1,
-                                            name: "PlayToolBar" });
-            this.widget.get_style_context().add_class('toolbar');
-            this.rowGrid.attach(this.widget, 1, 0, 1, 2);
-                       
-            this._box = new Gtk.Box({ orientation: Gtk.Orientation.HORIZONTAL,
-                                      name: "Playbox" });
-            this._group = new Gtk.ToolItem({ child: this._box, name: "PlayGroup"});
-            this.widget.insert(this._group, -1);
-            
-            // play button
-            this.playImage = Gtk.Image.new();
-            this.playImage.set_from_icon_name('media-playback-start-symbolic', Gtk.IconSize.BUTTON);
-            this._playListButton = new Gtk.Button({ hexpand: false,
-                                                    name: "PlayButton" });
-            this._playListButton.set_image(this.playImage);
-            this._box.pack_start(this._playListButton, false, true, 0);
-            this._playListButton.show();
-            this._playListButton.connect('clicked', Lang.bind(this,
+        if (this._endIdx == -1) {
+            this._scrolledWin.get_style_context().add_class('emptyGrid');
+            this._addEmptyPage();
+        } else {       
+            this.listBox = Gtk.ListBox.new({ hexpand: true,
+                                             vexpand: true });
+            this._scrolledWin.add(this.listBox);
+            this.listBox.set_selection_mode(Gtk.SelectionMode.SINGLE);
+            this.listBox.set_header_func(null);
+            this.listBox.set_activate_on_single_click(true);
+            this.listBox.connect("row-selected", Lang.bind(this,
                 function(){
-                    let row = this.listBox.get_selected_row();
-                    play.passSelected(row); 
-                    let gridForName = row.get_child();
-                    let idx = parseInt(gridForName.name);                   
-                    let file = this._files[idx];
-                    this.onPlayPauseToggled(row, file);
+                    this.rowGridCallback(this.listBox.get_selected_row())
                 }));
+            this.listBox.show();
                 
-            this.pauseWidget = new Gtk.Toolbar({ show_arrow: false,
-                                                 halign: Gtk.Align.END,
-                                                 valign: Gtk.Align.FILL,
-                                                 icon_size: Gtk.IconSize.BUTTON,
-                                                 opacity: 1,
-                                                 name: "PauseToolBar" });
-            this.pauseWidget.get_style_context().add_class('toolbar');
-            this.rowGrid.attach(this.pauseWidget, 1, 0, 1, 2);
-                       
-            this._pauseBox = new Gtk.Box({ orientation: Gtk.Orientation.HORIZONTAL,
-                                           name: "Pausebox" });
-            this._pauseGroup = new Gtk.ToolItem({ child: this._pauseBox, name: "PauseGroup"});
-            this.pauseWidget.insert(this._pauseGroup, -1);
+            this._files = [];
+            this._files = list.getFilesInfoForList();
             
-            // pause button
-            this.pauseImage = Gtk.Image.new();
-            this.pauseImage.set_from_icon_name('media-playback-pause-symbolic', Gtk.IconSize.BUTTON);
-            this._pauseListButton = new Gtk.Button({ hexpand: false,
-                                                     name: "PauseButton" });
-            this._pauseListButton.set_image(this.pauseImage);
-            this._pauseBox.pack_start(this._pauseListButton, false, true, 0);
-            this._pauseListButton.show();
-            this._pauseListButton.connect('clicked', Lang.bind(this,
-                function(){
-                    let row = this.listBox.get_selected_row();
-                    this.onPause(row);
-                }));
-            
-            this._fileName = new Gtk.Label({ use_markup: true,
-                                             halign: Gtk.Align.START,
-                                             valign: Gtk.Align.START,
-                                             ellipsize: true,
-                                             xalign: 0,
-                                             width_chars: 40,
-                                             margin_top: 5,
-                                             margin_left: 15,
-                                             name: "FileNameLabel" });
-            let markup = ('<b>'+ this._files[i].fileName + '</b>');
-            this._fileName.label = markup;
-            this._fileName.set_no_show_all(true);
-            this.rowGrid.attach(this._fileName, 2, 0, 1, 3);
-            this._fileName.show();
-            
-            this._playLabelBox = new Gtk.Box({ orientation: Gtk.Orientation.HORIZONTAL,
-                                               name: "PlayLabelBox",
-                                               height_request: 36 });
-            this.rowGrid.attach(this._playLabelBox, 2, 1, 1, 1);
-            this._playLabelBox.show();
-                    
-            this.playDurationLabel = new Gtk.Label({ margin_left: 15,
-                                                     halign: Gtk.Align.END,
+            for (let i = this._startIdx; i <= this._endIdx; i++) {
+                this.rowGrid = new Gtk.Grid({ orientation: Gtk.Orientation.VERTICAL,
+                                              height_request: 45,
+                                              width_request: 675,
+                                              hexpand: true,
+                                              vexpand: true,
+                                              column_homogeneous: true,
+                                              name: i.toString() });
+                this.rowGrid.set_orientation(Gtk.Orientation.HORIZONTAL);
+                this.listBox.add(this.rowGrid);
+                this.rowGrid.show();                
+                let rtl = Gtk.Widget.get_default_direction() == Gtk.TextDirection.RTL;
+
+                // play button
+                this.playImage = Gtk.Image.new();
+                this.playImage.set_from_icon_name(rtl ? 'media-playback-start-rtl-symbolic' :
+                                                        'media-playback-start-symbolic',
+                                                  Gtk.IconSize.BUTTON);
+                this._playListButton = new Gtk.Button({ hexpand: false,
+                                                        vexpand: true,
+                                                        name: "PlayButton" });
+                this._playListButton.set_image(this.playImage);
+                this._playListButton.set_tooltip_text(_("Play"));
+                this.rowGrid.attach(this._playListButton, 0, 0, 1, 2);
+                this._playListButton.hide();
+                this._playListButton.connect('clicked', Lang.bind(this,
+                    function(){
+                        let row = this.listBox.get_selected_row();
+                        play.passSelected(row); 
+                        let gridForName = row.get_child();
+                        let idx = parseInt(gridForName.name);                   
+                        let file = this._files[idx];
+                        this.onPlayPauseToggled(row, file);
+                    }));
+                
+                // pause button
+                this.pauseImage = Gtk.Image.new();
+                this.pauseImage.set_from_icon_name('media-playback-pause-symbolic', Gtk.IconSize.BUTTON);
+                this._pauseListButton = new Gtk.Button({ hexpand: false,
+                                                         vexpand: true,
+                                                         name: "PauseButton" });
+                this._pauseListButton.set_image(this.pauseImage);
+                this._pauseListButton.set_tooltip_text(_("Pause"));
+                this.rowGrid.attach(this._pauseListButton, 0, 0, 1, 2);
+                this._pauseListButton.hide();
+                this._pauseListButton.connect('clicked', Lang.bind(this,
+                    function(){
+                        let row = this.listBox.get_selected_row();
+                        this.onPause(row);
+                    }));
+                
+                this._fileName = new Gtk.Label({ use_markup: true,
+                                                 halign: Gtk.Align.START,
+                                                 valign: Gtk.Align.START,
+                                                 ellipsize: true,
+                                                 xalign: 0,
+                                                 width_chars: 40,
+                                                 margin_top: 5,
+                                                 margin_left: rtl ? 0 : 15,
+                                                 margin_right: rtl ? 15 : 0,
+                                                 name: "FileNameLabel" });
+                let markup = ('<b>'+ this._files[i].fileName + '</b>');
+                this._fileName.label = markup;
+                this._fileName.set_no_show_all(true);
+                this.rowGrid.attach(this._fileName, 1, 0, 10, 3);
+                this._fileName.show();
+                
+                this._playLabelBox = new Gtk.Box({ orientation: Gtk.Orientation.HORIZONTAL,
+                                                   name: "PlayLabelBox",
+                                                   height_request: 45 });
+                this.rowGrid.attach(this._playLabelBox, 1, 1, 10, 1);
+                this._playLabelBox.show();
+                        
+                this.playDurationLabel = new Gtk.Label({ margin_left: rtl ? 0 : 15,
+                                                         margin_right: rtl ? 15 : 0,
+                                                         halign: Gtk.Align.END,
+                                                         valign: Gtk.Align.END,
+                                                         margin_top: 5,
+                                                         name: "PlayDurationLabel" });
+                this.fileDuration = this._formatTime(this._files[i].duration/Gst.SECOND);
+                this.playDurationLabel.label = this.fileDuration;
+                this._playLabelBox.pack_start(this.playDurationLabel, false, true, 0);
+                this.playDurationLabel.show();
+                
+                this.dividerLabel = new Gtk.Label({ halign: Gtk.Align.START,
+                                                    name: "DividerLabel",
+                                                    valign: Gtk.Align.END,
+                                                    margin_top: 5 });
+                this.dividerLabel.label = "/";
+                this._playLabelBox.pack_start(this.dividerLabel, false, true, 0);
+                this.dividerLabel.hide();
+                
+                this.playTimeLabel = new Gtk.Label({ halign: Gtk.Align.START,
+                                                     name: "PlayTimeLabel",
                                                      valign: Gtk.Align.END,
-                                                     margin_top: 5,
-                                                     name: "PlayDurationLabel" });
-            this.fileDuration = this._formatTime(this._files[i].duration/Gst.SECOND);
-            this.playDurationLabel.label = this.fileDuration;
-            this._playLabelBox.pack_start(this.playDurationLabel, false, true, 0);
-            this.playDurationLabel.show();
-            
-            this.dividerLabel = new Gtk.Label({ halign: Gtk.Align.START,
-                                                name: "DividerLabel",
-                                                valign: Gtk.Align.END,
-                                                margin_top: 5 });
-            this.dividerLabel.label = "/";
-            this._playLabelBox.pack_start(this.dividerLabel, false, true, 0);
-            this.dividerLabel.hide();
-            
-            this.playTimeLabel = new Gtk.Label({ halign: Gtk.Align.START,
-                                                 name: "PlayTimeLabel",
-                                                 valign: Gtk.Align.END,
-                                                 margin_top: 5 });
-            this.playTimeLabel.label = "0:00";
-            this._playLabelBox.pack_start(this.playTimeLabel, false, true, 0);
-            this.playTimeLabel.hide();
-            
-            this.waveFormGrid = new Gtk.Grid({ orientation: Gtk.Orientation.VERTICAL,
-                                               height_request: 45,
-                                               width_request: 380,
-                                               valign: Gtk.Align.FILL,
-                                               name: "WaveFormGrid" });
-            this.waveFormGrid.set_no_show_all(true);
-            this.rowGrid.attach(this.waveFormGrid, 9, 1, 1, 2);
+                                                     margin_top: 5 });
+                this.playTimeLabel.label = "0:00";
+                this._playLabelBox.pack_start(this.playTimeLabel, false, true, 0);
+                this.playTimeLabel.hide();
+                
+                this.waveFormGrid = new Gtk.Grid({ orientation: Gtk.Orientation.VERTICAL,
+                                                   height_request: 45,
+                                                   width_request: 380,
+                                                   valign: Gtk.Align.FILL,
+                                                   hexpand: true,
+                                                   vexpand: true,
+                                                   name: "WaveFormGrid" });
+                this.waveFormGrid.set_no_show_all(true);
+                this.rowGrid.attach(this.waveFormGrid, 11, 1, 18, 4);
+                this.waveFormGrid.show();
+                
+                // info button
+                this._info = new Gtk.Button({ hexpand: false,
+                                              vexpand: true,
+                                              name: "InfoButton" });
+                this._info.image = Gtk.Image.new_from_icon_name("dialog-information-symbolic", Gtk.IconSize.BUTTON);
+                this._info.connect("clicked", Lang.bind(this,
+                    function() {
+                        let row = this.listBox.get_selected_row();
+                        let gridForName = row.get_child();
+                        let idx = parseInt(gridForName.name);                    
+                        let file = this._files[idx];
+                        this._onInfoButton(file);
+                    }));
+                this._info.set_tooltip_text(_("Info"));
+                this._info.get_style_context().add_class(rtl ? "toolbarEnd" : "toolbarSecond");
+                this.rowGrid.attach(this._info, 29, 0, 1, 2);
+                this._info.hide();
 
-            this.waveFormGrid.show();
-
-            this.widgetInfo = new Gtk.Toolbar({ show_arrow: false,
-                                                halign: Gtk.Align.END,
-                                                valign: Gtk.Align.FILL,
-                                                icon_size: Gtk.IconSize.BUTTON,
-                                                opacity: 1,
-                                                name: "InfoToolbar" });
-            this.rowGrid.attach(this.widgetInfo, 10, 0, 1, 2);
-            this.widgetInfo.get_style_context().add_class('toolbar');
-            
-            this._boxInfo = new Gtk.Box({ orientation: Gtk.Orientation.HORIZONTAL });
-            this._groupInfo = new Gtk.ToolItem({ child: this._boxInfo });
-            this.widgetInfo.insert(this._groupInfo, -1);
-            
-            // info button
-            this._info = new Gtk.Button({ hexpand: false,
-                                          name: "InfoButton" });
-            this._info.image = Gtk.Image.new_from_icon_name("dialog-information-symbolic", Gtk.IconSize.BUTTON);
-            this._info.connect("clicked", Lang.bind(this,
-                function() {
-                    let row = this.listBox.get_selected_row();
-                    let gridForName = row.get_child();
-                    let idx = parseInt(gridForName.name);                    
-                    let file = this._files[idx];
-                    this._onInfoButton(file);
-                }));
-            this._info.set_tooltip_text(_("Info"));
-            this._boxInfo.add(this._info);
-            this._info.hide();
-            
-            this.widgetDelete = new Gtk.Toolbar({ show_arrow: false,
-                                                  halign: Gtk.Align.END,
-                                                  valign: Gtk.Align.FILL,
-                                                  icon_size: Gtk.IconSize.BUTTON,
-                                                  opacity: 1,
-                                                  name: "DeleteToolbar" });
-            this.widgetDelete.get_style_context().add_class('toolbarEnd');
-            this.rowGrid.attach(this.widgetDelete, 11, 0, 1, 2);
-            
-            this._boxDelete = new Gtk.Box({ orientation: Gtk.Orientation.HORIZONTAL });
-            this._groupDelete = new Gtk.ToolItem({ child: this._boxDelete });
-            this.widgetDelete.insert(this._groupDelete, -1);
-
-            // delete button
-            this._delete = new Gtk.Button({ hexpand: false,
-                                            name: "DeleteButton" });
-            this._delete.image = Gtk.Image.new_from_icon_name("user-trash-symbolic", Gtk.IconSize.BUTTON);
-            this._delete.connect("clicked", Lang.bind(this,
-                function() {
-                    this._deleteFile(this.listBox.get_selected_row());
-                }));
-            this._delete.set_tooltip_text(_("Delete"));
-            this._boxDelete.add(this._delete);
-            this._boxDelete.show();
-            
-            this._separator = Gtk.Separator.new(Gtk.Orientation.HORIZONTAL);
-            this._separator.set_sensitive(false);
-            this.listBox.add(this._separator);
-            this.selectionRow = this._separator.get_parent();
-            this.selectionRow.set_sensitive(false);
-            this._separator.show();
+                // delete button
+                this._delete = new Gtk.Button({ hexpand: false,
+                                                name: "DeleteButton" });
+                this._delete.image = Gtk.Image.new_from_icon_name("user-trash-symbolic", Gtk.IconSize.BUTTON);
+                this._delete.connect("clicked", Lang.bind(this,
+                    function() {
+                        this._deleteFile(this.listBox.get_selected_row());
+                    }));
+                this._delete.set_tooltip_text(_("Delete"));
+                this.rowGrid.attach(this._delete, 30, 0, 1, 2);
+                this._delete.get_style_context().add_class(rtl ? "toolbarSecond" : "toolbarEnd");
+                this._delete.hide();
+                
+                this._separator = Gtk.Separator.new(Gtk.Orientation.HORIZONTAL);
+                this._separator.set_sensitive(false);
+                this.listBox.add(this._separator);
+                this.selectionRow = this._separator.get_parent();
+                this.selectionRow.set_sensitive(false);
+                this._separator.show();
+            }
         }
         list.monitorListview();
     },
@@ -551,7 +509,11 @@ const MainView = new Lang.Class({
     listBoxRefresh: function() {
         this.destroyLoadMoreButton();        
         previousSelRow = null;
-        this.listBox.set_selection_mode(Gtk.SelectionMode.NONE);
+        
+        if (this.listBox) {
+            this.listBox.set_selection_mode(Gtk.SelectionMode.NONE);
+        }
+
         list.setListTypeRefresh();  
         list.enumerateDirectory();         
     },
@@ -566,7 +528,6 @@ const MainView = new Lang.Class({
     },
     
     scrolledWinDelete: function() {
-        //let w = this.rowGrid.get_allocated_width();
         this._scrolledWin.destroy();
         this.scrolledWinAdd(); 
     },
@@ -593,7 +554,9 @@ const MainView = new Lang.Class({
     
     rowGridCallback: function(selectedRow) {
         this.destroyLoadMoreButton();
+        
         if (selectedRow) {
+        
             if (previousSelRow != null) {
                 this.hasPreviousSelRow();
             }  
@@ -612,9 +575,9 @@ const MainView = new Lang.Class({
                         child.sensitive = true;
                 }));
         }
-    },    
-    
-    _getFileNameFromRow: function(selected) {
+    },
+
+    _getFileFromRow: function(selected) {
         this._selected = selected;
         let fileForAction = null;
         let rowWidget = this._selected.get_child(this.fileName);
@@ -623,7 +586,8 @@ const MainView = new Lang.Class({
             
                 if (child.name == "FileNameLabel") {
                     let name = child.get_text();
-                    fileForAction = fileUtil.loadFile(name);
+                    let application = Gio.Application.get_default();
+                    fileForAction = application.saveDir.get_child_for_display_name(name);
                 }
              }));
              
@@ -632,14 +596,14 @@ const MainView = new Lang.Class({
     
     _deleteFile: function(selected) {
         this._selected = selected;
-        let fileToDelete = this._getFileNameFromRow(this._selected);
-        fileUtil.deleteFile(fileToDelete);
+        let fileToDelete = this._getFileFromRow(this._selected);
+        fileToDelete.delete_async(GLib.PRIORITY_DEFAULT, null, null);
     },
     
     loadPlay: function(selected) {
         this._selected = selected;
-        let fileToPlay = this._getFileNameFromRow(this._selected);
-        
+        let fileToPlay = this._getFileFromRow(this._selected);
+
         return fileToPlay;
     }, 
     
@@ -669,18 +633,19 @@ const MainView = new Lang.Class({
     
     onPause: function(listRow) {
         this.activeState = play.getPipeStates();
+        
         if (this.activeState == PipelineStates.PLAYING) {
             play.pausePlaying();
             let rowWidget = listRow.get_child(this.widget);
             rowWidget.foreach(Lang.bind(this,
                 function(child) {
                 
-                    if (child.name == "PauseToolbar") {
+                    if (child.name == "PauseButton") {
                         child.hide();
                         child.sensitive = false;
                     }  
                            
-                    if (child.name == "PlayToolBar" ) {
+                    if (child.name == "PlayButton" ) {
                         child.show();
                         child.sensitive = true;
                     }
@@ -700,12 +665,12 @@ const MainView = new Lang.Class({
             rowWidget.foreach(Lang.bind(this,
                 function(child) {
                            
-                    if (child.name == "InfoToolbar" || child.name == "DeleteToolbar" || child.name == "PlayToolBar" ) {
+                    if (child.name == "InfoButton" || child.name == "DeleteButton" || child.name == "PlayButton" ) {
                         child.hide();
                         child.sensitive = false;
                     }
                     
-                    if (child.name == "PauseToolbar") {
+                    if (child.name == "PauseButton") {
                         child.show();
                         child.sensitive = true;
                     }    
@@ -728,7 +693,7 @@ const MainView = new Lang.Class({
                         child.sensitive = true;
                     }
                 }));
-             listRow.set_property("width-request", width);
+            listRow.set_property("width-request", width);
             
             if (this.activeState != PipelineStates.PAUSED) {
                 wave = new Waveform.WaveForm(this.wFGrid, selFile);
@@ -745,20 +710,29 @@ const RecordButton = new Lang.Class({
         this.parent();
         this.image = Gtk.Image.new_from_icon_name('media-record-symbolic', Gtk.IconSize.BUTTON);
         this.set_always_show_image(true);
-        this.set_label("Record");
+        this.set_valign(Gtk.Align.CENTER);
+        this.set_label(_("Record"));
+        this.get_style_context().add_class('text-button');
         this.connect("clicked", Lang.bind(this, this._onRecord));
     },
     
     _onRecord: function() {
         view.destroyLoadMoreButton();
         view.hasPreviousSelRow();
-        view.listBox.set_selection_mode(Gtk.SelectionMode.NONE);
+        
+        if (view.listBox) {
+            view.listBox.set_selection_mode(Gtk.SelectionMode.NONE);
+        } else {
+            view.emptyGrid.destroy();
+        }
+            
         this.set_sensitive(false);
         setVisibleID = ActiveArea.RECORD;
         view.recordGrid.show_all();
         
         if (activeProfile == null)
             activeProfile = 0; 
+            
         audioProfile.profile(activeProfile);
         view._record.startRecording(activeProfile);
         wave = new Waveform.WaveForm(view.recordGrid);
