@@ -11,9 +11,7 @@
  * Library General Public License for more details.
  *
  * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library; if not, see <http://www.gnu.org/licenses/>.
  *
  *  Author: Meg Ford <megford@gnome.org>
  *
@@ -264,33 +262,15 @@ const Record = new Lang.Class({
 const BuildFileName = new Lang.Class({ 
     Name: 'BuildFileName',
 
-    buildPath: function() {
-        let initialFileName = [];
-        initialFileName.push(GLib.get_home_dir());
-        /* Translators: "Recordings" here refers to the name of the directory where the application places files */
-        initialFileName.push(_("Recordings"));
-        
-        return initialFileName;
-    },
-    
-    ensureDirectory: function(name) {
-        this._name = name;    
-        let dirName = GLib.build_filenamev(this._name);
-        let namedDir = GLib.mkdir_with_parents(dirName, 0775);
-    },
-    
     buildInitialFilename: function() {
         let fileExtensionName = MainWindow.audioProfile.fileExtensionReturner();
-        let dir = this.buildPath();
+        let dir = Gio.Application.get_default().saveDir;
         this.dateTime = GLib.DateTime.new_now_local();
         /* Translators: "Audio from %Y-%m-%d %H:%M:%S" is the default name assigned to a file created
             by the application (for example, "Audio from 2013-10-05 13:25:21.ogg"). */
-        let dateTimeString = this.dateTime.format(_("Audio from %Y-%m-%d %H:%M:%S"));  
-         dir.push(dateTimeString + fileExtensionName);
-        // Use GLib.build_filenamev to work around missing vararg functions.
-        let title = GLib.build_filenamev(dir);
-        let file = Gio.file_new_for_path(title);
-        
+        let dateTimeString = this.dateTime.format(_("Audio from %Y-%m-%d %H:%M:%S"));
+        let file = dir.get_child_for_display_name(dateTimeString + fileExtensionName);
+
         return file;
     },
     
